@@ -336,7 +336,9 @@ class GroupCmdTestCase(SambaToolCmdTest):
 
 
     def test_move(self):
-        full_ou_dn = str(self.samdb.normalize_dn_in_domain("OU=movetest"))
+        full_ou_dn = str(self.samdb.normalize_dn_in_domain("OU=movetest_grp"))
+        self.addCleanup(self.samdb.delete, full_ou_dn, ["tree_delete:1"])
+
         (result, out, err) = self.runsubcmd("ou", "add", full_ou_dn)
         self.assertCmdSuccess(result, out, err)
         self.assertEqual(err, "", "There shouldn't be any error message")
@@ -363,10 +365,6 @@ class GroupCmdTestCase(SambaToolCmdTest):
             self.assertIn('Moved group "%s" into "%s"' %
                           (group["name"], new_dn), out)
 
-        (result, out, err) = self.runsubcmd("ou", "delete", full_ou_dn)
-        self.assertCmdSuccess(result, out, err,
-                              "Failed to delete ou '%s'" % full_ou_dn)
-
     def test_show(self):
         """Assert that we can show a group correctly."""
         (result, out, err) = self.runsubcmd("group", "show", "Domain Users",
@@ -576,11 +574,13 @@ template """
         self.assertTrue("Total groups: {0}".format(total_groups) in out,
                         "Total groups not reported correctly")
 
-    def _random_user(self, base={}):
+    def _random_user(self, base=None):
         '''
         create a user with random attribute values, you can specify
         base attributes
         '''
+        if base is None:
+            base = {}
         user = {
             "name": self.randomName(),
             "password": self.random_password(16),
